@@ -286,11 +286,15 @@ class WebSocketZMQBridgeHandler(websocket.WebSocketHandler):
 
 if __name__ == '__main__':
     broker = IFBroker(f"tcp://*:{IFDefinition.DEFAULT_PORT_TCP}")
-    broker.startWebSocket(IFDefinition.DEFAULT_PORT_WEBSOCKET_SSL, '/ws/',
-    {
-        "certfile": "../server.crt",
-        "keyfile": "../server.key",
-    }
-    )
+    # broker.startWebSocket(IFDefinition.DEFAULT_PORT_WEBSOCKET_SSL, '/ws/',
+    # {
+    #     "certfile": "../server.crt",
+    #     "keyfile": "../server.key",
+    # }
+    # )
     print('started')
+
+    from interactionfreepy import IFWorker
+    print(IFWorker('tcp://127.0.0.1').listServiceNames())
+
     IFLoop.join()
